pub mod model;
pub use model::historic::Historic;
pub use model::reference::*;
pub use model::valid::Validate;
pub use model::Model;
pub use mongod_derive as derive;
pub use mongodb;

/// Get a `MongoDB` Client from the environment
#[macro_export]
macro_rules! get_mongo {
    () => {
        mongodb::Client::with_uri_str(std::env::var("DB_URI").unwrap())
            .await
            .unwrap()
    };
}

/// Get a database collection
#[macro_export]
macro_rules! col {
    ($db:expr, $col:expr) => {
        $db.database("owl")
            .collection::<mongodb::bson::Document>($col)
    };
}

/// Collect database results into a `Vec<_>`
#[macro_export]
macro_rules! collect_results {
    ($res:expr) => {{
        use futures::stream::TryStreamExt;
        let mut ret = vec![];

        while let Some(doc) = $res.try_next().await.unwrap() {
            ret.push(doc);
        }

        ret
    }};
}

/// `MongoDB` filter for the `_id` field.
#[macro_export]
macro_rules! id_of {
    ($id:expr) => {
        mongodb::bson::doc! { "_id": $id}
    };
}
